bact-archiver: access to epics archiver appliance
=================================================

The epics archiver appliance provides support based on
google's protocol buffer.

This package provides a client implementation. Its implementation uses
c++ files generated by the protocol buffer compiler and cython
interface code.

See package documentation for further details.
